@@ -62,6 +62,29 @@ def sparql_request(unpid_site_list: list):
     #print(unpid_site_list_str)
 
 
+    '''
+SELECT
+    ?entry
+    ?position
+	?type
+FROM <http://sparql.uniprot.org/uniprot>
+WHERE {
+    VALUES (?entry ?position) {(uniprotkb:P01375 44)
+    (uniprotkb:P00533 41)
+    (uniprotkb:P15692 39)
+    (uniprotkb:P02649 50)
+    (uniprotkb:P04637 100)
+    (uniprotkb:P08887 41)
+    (uniprotkb:P42898 41)
+    (uniprotkb:P03372 41)
+    }
+    ?entry up:annotation ?annotation .
+    ?annotation up:range ?range ;
+               a ?type 
+  #FILTER ( REGEX(STR(?annotation), "Similarity_Annotation"))
+} ORDER BY DESC(?entry) ASC(?position)
+    '''
+
     prefix="""PREFIX uniprotkb: <http://purl.uniprot.org/uniprot/>
 PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
 PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
@@ -69,7 +92,7 @@ PREFIX faldo: <http://biohackathon.org/resource/faldo#>
 PREFIX up: <http://purl.uniprot.org/core/>
 PREFIX ec: <http://purl.uniprot.org/enzyme/>"""
 
-
+    #TODO: Add up:Similarity_Annotation, 
     new_entry_length_pos_query = prefix + """
 SELECT
     ?entry
@@ -183,8 +206,6 @@ SELECT
     ?position
     ?ec
     ?rhea
-    ?type
-    ?comment
 FROM <http://sparql.uniprot.org/uniprot>
 WHERE {
     VALUES (?entry ?position) {""" + unpid_site_list_str + """
@@ -215,6 +236,30 @@ WHERE {
     }
 
 #Order desc by entry and ascending by position afterwards
+} ORDER BY DESC(?entry) ASC(?position)"""
+
+    query_comment = prefix + """
+SELECT
+    ?entry
+    ?position
+    ?type
+    ?comment
+FROM <http://sparql.uniprot.org/uniprot>
+WHERE {
+    VALUES (?entry ?position) {""" + unpid_site_list_str + """}
+    ?entry up:sequence ?sequence .
+    ?entry up:annotation ?annotation .
+    ?annotation up:range ?range ;
+               a ?type .
+    ?range faldo:begin
+        [ faldo:position ?begin ; faldo:reference ?sequence ] ;
+            faldo:end
+        [ faldo:position ?end ; faldo:reference ?sequence ] .
+    FILTER (?begin <= ?position && ?position <= ?end)
+	OPTIONAL {
+        ?annotation rdfs:comment ?comment .
+    }
+#Order desc by entry and ascending by position afterwards
 } ORDER BY DESC(?entry) ASC(?position)"""
 
     # Grabs the annotation by parts to maximize the amount we receive from the uniprot server
@@ -232,6 +277,8 @@ WHERE {
     subcell_annot = request_annot(query_entry_subcellular)
     #print(subcell_annot.head(15))
     extras_annot = request_annot(query_ec_rhea_type)
+    comment_annot = request_annot(query_comment)
+    #print(comment_annot.head(15))
     # Creates blank dataframes if uniprot did not return that info
     if region_annot is None:
         region_annot = pd.DataFrame(columns=["entry", " position", " lengthOfSequence", " begin", " end", " regionOfInterest"])
@@ -246,9 +293,14 @@ WHERE {
     else:
         subcell_annot.dropna(how="any", inplace=True)
     if extras_annot is None:
-       extras_annot = pd.DataFrame(columns=["entry", " position", " ec", " rhea", " type", " comment"])
+       extras_annot = pd.DataFrame(columns=["entry", " position", " ec", " rhea"])
     else:
         extras_annot.dropna(how="all", inplace=True)  # TODO: I will likely need to change this back to all later
+    
+    if comment_annot is None:
+        comment_annot = pd.DataFrame(columns=["entry", " position", " type", " comment"])
+    else:
+        comment_annot.dropna(how="all", inplace=True)
 
     # Full outer joins the annotations to preserve all info possible
     full_annot = region_annot
@@ -261,6 +313,8 @@ WHERE {
         del(subcell_annot)
         full_annot = full_annot.merge(extras_annot, how="outer", on=["entry", " position"])
         del(extras_annot)
+        full_annot = full_annot.merge(comment_annot, how="outer", on=["entry", " position"])
+        del(comment_annot)
     except KeyError:
         print(full_annot)
         #print(isinstance(full_annot, pd.DataFrame))
@@ -285,7 +339,7 @@ def request_annot(query: str, attempts_left=10):
         if "<!DOCTYPE html SYSTEM \"about:legacy-compat\">" in r.text:  # This just means it returned a 500 error
             if attempts_left > 0:
                 sleep(time_to_sleep)
-                print("\033[93m {}\033[00m".format(f"Attempts used: {11 - attempts_left}"))
+                print("\033[93m {}\033[00m".format(f"\nAttempts used: {11 - attempts_left}"), end='')
                 return request_annot(query, attempts_left - 1)
             else:
                 return None  # TODO: remove this once Uniprot fixes their stuff
@@ -295,7 +349,7 @@ def request_annot(query: str, attempts_left=10):
     except (pd.errors.ParserError, requests.exceptions.ConnectionError):
         if attempts_left > 0:
             sleep(time_to_sleep)
-            print("\033[93m {}\033[00m".format(f"Attempts used: {11 - attempts_left}"))
+            print("\033[93m {}\033[00m".format(f"\nAttempts used: {11 - attempts_left}"), end='')
             return request_annot(query, attempts_left - 1)
         else:
             return None  # TODO: remove this once Uniprot fixes their stuff
@@ -329,7 +383,10 @@ def process_sparql_output(output_df, sparql_dict: dict) -> list:
                 new_str.append(chunk.replace("http://purl.uniprot.org/core/", ""))
             elif isinstance(chunk, str) and "http://purl.uniprot.org/locations/" in chunk:
                 new_chunk = chunk.replace("http://purl.uniprot.org/locations/", "")
-                new_str.append(subcellular_location_dict[new_chunk.zfill(4)])  # Converts the number location to descriptor
+                try:
+                    new_str.append(subcellular_location_dict[new_chunk.zfill(4)])  # Converts the number location to descriptor
+                except KeyError:
+                    new_str.append("")
             elif isinstance(chunk, str) and "http://purl.uniprot.org/enzyme/" in chunk:
                 new_chunk = chunk.replace("http://purl.uniprot.org/enzyme/", "")
                 new_str.append(ec_id_to_description_dict[new_chunk])
@@ -344,13 +401,13 @@ def process_sparql_output(output_df, sparql_dict: dict) -> list:
     #sparql_dict = dict()  # This gets used by the main program to connect these annotations to the rest of the data.
     output_lines = output_df
     if len(output_lines) == 1 or (not isinstance(output_lines, str) and output_lines.empty):
-        print("Failed to get annotations")
+        print("\nUniprot Error: Failed to get annotations", end='')
         return output_list, sparql_dict
     
     try:
         position_index = output_lines.columns.get_loc(" position")
     except (AttributeError, KeyError):
-        print("Missing the Position column")
+        print("\nUniprot Error: Missing the Position column", end='')
         return output_list, sparql_dict
 
     # get the subcellular location from UniProt
